@@ -1424,8 +1424,10 @@ Please remove these instructions from your message.")
 	(vm-load-init-file)
 	(when vm-enable-addons
 	  (vm-rfaddons-infect-vm 0 vm-enable-addons)
-	  (require 'vm-summary-faces)
-	  (vm-summary-faces-mode 1))
+	  (when (or (member 'summary-faces vm-enable-addons)
+		    (eq t vm-enable-addons))
+	    (require 'vm-summary-faces)
+	    (vm-summary-faces-mode 1)))
 	(if (not vm-window-configuration-file)
 	    (setq vm-window-configurations vm-default-window-configuration)
 	  (or (vm-load-window-configurations vm-window-configuration-file)
